@@ -39,8 +39,17 @@ class login:
             print('Invalid Username Or Password!')
             sys.exit()
 class verify:
-    def verify(auth_id, mail, subject, mail_text):
+    def verify(auth_id, mail, subject, mail_text, notlogin):
         global code
+        login=requests.get('https://pastebin.com/'+auth_id)
+        email=mail.encode('utf-8')
+        gmail=hashlib.md5(email)
+        logmail=gmail.hexdigest()
+        if logmail in login.text:
+            pass
+        else:
+            print(notlogin)
+            sys.exit()
         sec="1234567890"
         cod = []
         for x in range(6):
@@ -63,7 +72,7 @@ class verify:
     class getotp:
         def otp(mail, otp, alert_mail, alert_text, warn_mail, warn_text, warn_subject, alert_subject):
             if otp==code:
-                if warn_mail=='yes':
+                if warn_mail=='on':
                     get_ip=requests.get('https://get.geojs.io/v1/ip.json')
                     ip=(get_ip.json()['ip'])
                     get_info='https://get.geojs.io/v1/ip/geo/'+ip+'.json'
@@ -84,12 +93,12 @@ class verify:
                         server.ehlo()  # Can be omitted
                         server.login(sender_email, password)
                         server.sendmail(sender_email, receiver_email, message)
-                elif warn_mail=='no':
+                elif warn_mail=='off':
                     pass
                 else:
                     sys.exit()
             else:
-                if alert_mail=='yes':
+                if alert_mail=='on':
                     get_ip=requests.get('https://get.geojs.io/v1/ip.json')
                     ip=(get_ip.json()['ip'])
                     get_info='https://get.geojs.io/v1/ip/geo/'+ip+'.json'
@@ -111,7 +120,7 @@ class verify:
                         server.login(sender_email, password)
                         server.sendmail(sender_email, receiver_email, message)
 
-                elif alert_mail=='no':
+                elif alert_mail=='off':
                     print('Invalid Conformation Code')
                     sys.exit()
                 else:
